@@ -1,10 +1,12 @@
 #!/usr/bin/perl
 
 use strict;
-use Net::Syslogd;
+use warnings;
 use Getopt::Long qw(:config no_ignore_case); #bundling
 use Pod::Usage;
 
+use Net::Syslogd;
+
 my %opt;
 my ($opt_help, $opt_man);
 
@@ -13,6 +15,8 @@ GetOptions(
   '6!'          => \$opt{6},
   'directory=s' => \$opt{dir},
   'interface:i' => \$opt{interface},
+  'list!'       => \$opt{list},
+  'time!'       => \$opt{time},
   'write+'      => \$opt{write},
   'help!'       => \$opt_help,
   'man!'        => \$opt_man
@@ -27,8 +31,10 @@ if ($opt{6}) {
     $family = 6
 }
 
+$opt{time} = $opt{time} || 0;
+
 # -d is a directory, if it exists, assign it
-if (defined($opt{dir})) {
+if (defined $opt{dir}) {
 
     # replace \ with / for compatibility with UNIX/Windows
     $opt{dir} =~ s/\\/\//g;
@@ -43,7 +49,7 @@ if (defined($opt{dir})) {
     $opt{write} = 1 if (!$opt{write})
 }
 
-if (defined($opt{interface})) {
+if (defined $opt{interface}) {
     if (!(($opt{interface} > 0) && ($opt{interface} < 65536))) {
         print "$0: port not valid - $opt{interface}"
     }
@@ -66,37 +72,59 @@ printf "Listening on %s:%i\n", $syslogd->server->sockhost, $syslogd->server->soc
 while (1) {
     my $message = $syslogd->get_message();
 
-    if (!defined($message)) {
+    if (!defined $message) {
         printf "$0: %s\n", Net::Syslogd->error;
         exit 1
     } elsif ($message == 0) {
         next
     }
 
-    if (!defined($message->process_message())) {
+    if (!defined $message->process_message()) {
         printf "$0: %s\n", Net::Syslogd->error
     } else {
-        my $p = sprintf "%s\t%i\t%s\t%s\t%s\t%s\t%s\n", 
-                         $message->remoteaddr, 
-                         $message->remoteport, 
-                         $message->facility, 
-                         $message->severity, 
-                         $message->time, 
-                         $message->hostname, 
-                         $message->message;
+        my $p;
+        if ($opt{list}) {
+            $p = sprintf 
+                "Time       = %s\n" . 
+                "RemoteAddr = %s\n" . 
+                "RemotePort = %s\n" . 
+                "Severity   = %s\n" . 
+                "Facility   = %s\n" . 
+                "Time       = %s\n" . 
+                "Hostname   = %s\n" . 
+                "Message    = %s\n",
+                ($opt{time} ? yyyymmddhhmmss() : time),
+                $message->remoteaddr,
+                $message->remoteport,
+                $message->severity,
+                $message->facility,
+                $message->time,
+                $message->hostname,
+                $message->message
+        } else {
+            $p = sprintf "%s\t%s\t%i\t%s\t%s\t%s\t%s\t%s\n", 
+                ($opt{time} ? yyyymmddhhmmss() : time),
+                $message->remoteaddr,
+                $message->remoteport,
+                $message->severity,
+                $message->facility,
+                $message->time,
+                $message->hostname,
+                $message->message
+        }
         print $p;
 
         if ($opt{write}) {
             my $outfile;
-            if (defined($opt{dir}))  { $outfile = $opt{dir} . "/" }
+            if (defined $opt{dir}) { $outfile = $opt{dir} . "/" }
 
             if    ($opt{write} == 1) { $outfile .= "syslogd.log"               }
             elsif ($opt{write} == 2) { $outfile .= $message->facility . ".log" }
             else                     { $outfile .= $message->remoteaddr . ".log" }
 
-            if (open(OUT, ">>$outfile")) {
-                print OUT $p;
-                close(OUT)
+            if (open(my $OUT, '>>', $outfile)) {
+                print $OUT $p;
+                close $OUT
             } else {
                 print STDERR "$0: cannot open outfile - $outfile\n"
             }
@@ -104,6 +132,13 @@ while (1) {
     }
 }
 
+sub yyyymmddhhmmss {
+    my @time = localtime();
+    return (($time[5] + 1900) . ((($time[4] + 1) < 10)?("0" . ($time[4] + 1)):($time[4] + 1)) . (($time[3] < 10)?("0" . $time[3]):$time[3]) . (($time[2] < 10)?("0" . $time[2]):$time[2]) . (($time[1] < 10)?("0" . $time[1]):$time[1]) . (($time[0] < 10)?("0" . $time[0]):$time[0]))
+}
+
+__END__
+
 =head1 NAME
 
 SYSLOGD-SIMPLE - Simple Syslog Server
@@ -137,6 +172,12 @@ message format.  Syslog columns are:
  -i #             UDP Port to listen on.
  --interface      DEFAULT:  (or not specified) 514.
 
+ -l               Output list format.
+ --list           DEFAULT:  (or not specified) Line.
+
+ -t               Print time in human-readable yyyymmddhhmmss format.
+ --time           DEFAULT:  (or not specified) Unix epoch.
+
  -w               Log to "syslogd.log".
  -w -w            Log by facility in "<facility>.log".
  -w -w -w         Log by hostname in "<host>.log".
